from django.forms.renderers import TemplatesSetting


def inject_class(f, class_name):
    def inner(*args, **kwargs):
        result = f(*args, **kwargs)
        class_list = result.get("class", "")
        class_list = f"{class_list} {class_name}".strip()
        result["class"] = class_list
        return result

    return inner


class VerticalFormRenderer(TemplatesSetting):
    form_template_name = "frontend/forms/form.html"
    field_template_name = "frontend/forms/vertical_field.html"

    def get_class_names(self, input_type):
        if input_type == "checkbox":
            return "form-check-input"
        return "form-control"

    def render(self, template_name, context, request=None):
        if field := context.get("field"):
            field.build_widget_attrs = inject_class(
                field.build_widget_attrs,
                self.get_class_names(field.field.widget.input_type),
            )
        return super().render(template_name, context, request)


class InlineFormRenderer(VerticalFormRenderer):
    form_template_name = "frontend/forms/form.html"
    field_template_name = "frontend/forms/inline_field.html"
