from django.utils.functional import cached_property
from django.views.generic import TemplateView


class HtmxMixin(TemplateView):
    fragments = []

    @cached_property
    def is_htmx(self):
        return self.request.headers.get("HX-Request")

    def _get_fragment(self):
        if self.request.method == "POST":
            fragment = self.request.POST.get("fragment")
        else:
            fragment = self.request.GET.get("fragment")
        if fragment and fragment in self.fragments:
            return fragment

    def get_template_names(self):
        template_names = super().get_template_names()
        if self.is_htmx and (fragment := self._get_fragment()):
            return [f"{template_names[0]}#{fragment}"]
        return template_names

    def get_form_kwargs(self):
        result = super().get_form_kwargs()
        if self.is_htmx and (field_name := self.request.POST.get("hx-single-field")):
            result["single_field"] = field_name
        return result

    def form_valid(self, form):
        result = super().form_valid(form)
        if self.is_htmx and self._get_fragment():
            return self.get(self.request, *self.args, **self.kwargs)
        return result
